@@ -555,7 +555,9 @@ install_SL(){
     # For old file, like Debian Sarge (file 4.12-1) or RH9 (file-3.39-9):
     # In Debian Sarge: vmlinuz-2.6.8-2-686: x86 boot sector
     # In RH9: vmlinuz-2.4.20-28.9smp: x86 boot sector
-    if [ -n "$(LC_ALL=C file -Ls $i | grep -iE "(Linux x86 kernel|Linux kernel x86 boot executable|x86 boot sector)")" ]; then
+    # In OpenSuSE 11.3: "file -Ls vmlinuz" gives:
+    # vmlinuz: Linux/x86 Kernel, Setup Version 0x20a, bzImage, Version 3.2.0, Version 3.2.0-24, RO-rootFS, swap_dev 0x4, Normal VGA
+    if [ -n "$(LC_ALL=C file -Ls $i | grep -iE "(Linux x86 kernel|Linux kernel x86 boot executable|Linux\/x86 Kernel|x86 boot sector)")" ]; then
       # Ugly
       # we skip memtest, etherboot, freedos...
       if [ -z "$(LC_ALL=C echo $i | grep -iE "(memtest|eb.zli|memdisk|gpxe.lkn|ipxe.lkn|freedos|fdos)")" ]; then
